# This syntax reproduces the results reported in Table C.1 and Figure C.1

library(eRm)
library(ltm)
library(psych)
library(pairwise)

# Example with SD_slopes = .50 (resulting in MNSQs within the range 0.7-1.3):
set.seed(7878)
ipar <- runif(10, -1,1) # Item difficulties
sd.alpha_2 = .50 # Standard deviation of item slopes
alpha <- rlnorm(10, .2, sdlog = sd.alpha_2) # Item slopes
X_3 <- sim.2pl(1000, 10, discrim = alpha) # This generates a response matrix violating the parallel ICC requirement of the Rasch model
res_3 <- RM(X_3) # Rasch model parameter estimation
p.res_3 <- person.parameter(res_3)
eRm::itemfit(p.res_3) # Itemfit. See Table C.1.
ltm::cronbach.alpha(X_3) # Internal consistency (additional analysis, not reported in the text)

# Plot ICCs using the "ltm" package. See Figure C.1:
fit_2pl_ltm_3 <- ltm(X_3 ~  z1, IRT.param = TRUE,  control = list(iter.em = 1000))
fit_2pl_ltm_3
summary(fit_2pl_ltm_3)
plot(fit_2pl_ltm_3, type = "ICC", zrange = c(-4, 4), col = "black") # Plots ICCs

# PCA of the Rasch residuals using the package "pairwise":
pers_obj <- pairwise::pers(pair(X_3))
result <- pairwise::rfa(pers_obj)
summary(result)
plot(result)

# Population slopes (based on N = 3.000.000): See "The actual item slopes for the 10 items ranged from 0.86 to 3.06, a range of slopes that can hardly be called as being compatible with the equal-slopes requirement of Rasch model" on p. 320 
set.seed(7878)
ipar <- runif(10, -1,1) # Item difficulties
sd.alpha_2 = .5 # Standard deviation of item slopes
alpha <- rlnorm(10, .2, sdlog = sd.alpha_2)
X_pop <- sim.2pl(3000000, 10, discrim = alpha)
fit_2pl_ltm_pop <- ltm(X_pop ~  z1, IRT.param = TRUE,  control = list(iter.em = 1000))
fit_2pl_ltm_pop
summary(fit_2pl_ltm_pop)
plot(fit_2pl_ltm_pop)

# Resulting population item difficulties (Dffclt) and item slopes (Dscrmn):
#           Dffclt  Dscrmn
# Item 1   -1.093   1.627
# Item 2   -0.192   1.288
# Item 3   -1.828   1.139
# Item 4    1.216   1.092
# Item 5   -0.291   0.861
# Item 6   -0.167   3.062
# Item 7   -0.179   1.172
# Item 8    0.198   0.864
# Item 9   -0.745   1.365
# Item 10  -0.217   0.975

# Population-based item fit statistics according to the Rasch model. (Additional analysis not mentioned in ARM4)
res_pop_Rasch <- RM(X_pop)
p.res_pop <- person.parameter(res_pop_Rasch)
eRm::itemfit(p.res_pop)
